@@ -13,15 +13,11 @@ Y <- Y.1 * A + Y.0 * (1 - A)
 tmp <- data.frame(W1, W2, A, Y, Y.1, Y.0)
 truth <- mean(tmp$Y.1)
 
-sub <- lmtp_sub(tmp, "A", "Y", baseline = c("W1", "W2"), shift = static_binary_on, folds = 1)
-ipw <- lmtp_ipw(tmp, "A", "Y", baseline = c("W1", "W2"), shift = static_binary_on, folds = 1)
 tmle <- lmtp_tmle(tmp, "A", "Y", baseline = c("W1", "W2"), shift = static_binary_on, folds = 1)
 sdr <- lmtp_sdr(tmp, "A", "Y", baseline = c("W1", "W2"), shift = static_binary_on, folds = 1)
 
 # tests
 test_that("point treatment fidelity", {
-  expect_equal(truth, sub$theta, tolerance = 0.025)
-  expect_equal(truth, ipw$theta, tolerance = 0.025)
-  expect_equal(truth, tmle$theta, tolerance = 0.025)
-  expect_equal(truth, sdr$theta, tolerance = 0.025)
+  expect_equal(truth, tmle$estimate@x, tolerance = 0.01)
+  expect_equal(truth, sdr$estimate@x, tolerance = 0.01)
 })
